@@ -34,22 +34,3 @@ class TestInlineCalculation(AiidaTestCase):
         for i in [-4, 0, 3, 10]:
             calc, res = self.incr_inline(inp=Int(i))
             self.assertEqual(res['res'].value, i + 1)
-
-    def test_caching(self):
-        with enable_caching(InlineCalculation):
-            calc1, res1 = self.incr_inline(inp=Int(11))
-            calc2, res2 = self.incr_inline(inp=Int(11))
-            self.assertEquals(res1['res'].value, res2['res'].value, 12)
-            self.assertEquals(calc1.get_extra('_aiida_cached_from', calc1.uuid), calc2.get_extra('_aiida_cached_from'))
-
-    def test_caching_change_code(self):
-        with enable_caching(InlineCalculation):
-            calc1, res1 = self.incr_inline(inp=Int(11))
-
-            @make_inline
-            def incr_inline(inp):
-                return {'res': Int(inp.value + 2)}
-
-            calc2, res2 = incr_inline(inp=Int(11))
-            self.assertNotEquals(res1['res'].value, res2['res'].value)
-            self.assertFalse('_aiida_cached_from' in calc2.extras())
