@@ -33,6 +33,8 @@ else:
     AIIDA_CONFIG_FOLDER = '~/.aiida'
 
 CONFIG_FNAME = 'config.json'
+CONFIG_INDENT_SIZE = 4
+
 SECRET_KEY_FNAME = 'secret_key.dat'
 
 DAEMON_SUBDIR = 'daemon'
@@ -102,15 +104,15 @@ def _load_config():
     """
     import json
     from aiida.common.exceptions import MissingConfigurationError
-    from aiida.backends.settings import IN_DOC_MODE, DUMMY_CONF_FILE
+    from aiida.backends.settings import IN_RT_DOC_MODE, DUMMY_CONF_FILE
 
-    if IN_DOC_MODE:
+    if IN_RT_DOC_MODE:
         return DUMMY_CONF_FILE
 
     aiida_dir = os.path.expanduser(AIIDA_CONFIG_FOLDER)
     conf_file = os.path.join(aiida_dir, CONFIG_FNAME)
     try:
-        with open(conf_file, "r") as json_file:
+        with open(conf_file, 'r') as json_file:
             return json.load(json_file)
     except IOError:
         # No configuration file
@@ -132,14 +134,17 @@ def store_config(confs):
 
     :param confs: the dictionary to store.
     """
-    import json
+    from aiida.backends.settings import IN_RT_DOC_MODE
+    if IN_RT_DOC_MODE:
+        return
 
+    import json
     aiida_dir = os.path.expanduser(AIIDA_CONFIG_FOLDER)
     conf_file = os.path.join(aiida_dir, CONFIG_FNAME)
     old_umask = os.umask(DEFAULT_UMASK)
     try:
-        with open(conf_file, "w") as json_file:
-            json.dump(confs, json_file)
+        with open(conf_file, 'w') as json_file:
+            json.dump(confs, json_file, indent=CONFIG_INDENT_SIZE)
     finally:
         os.umask(old_umask)
 
@@ -187,8 +192,8 @@ def create_htaccess_file():
     exist yet), that is important
 
     .. note:: some default Apache configurations ignore the ``.htaccess``
-    files unless otherwise specified: read the documentation on
-    how to setup properly your Apache server!
+        files unless otherwise specified: read the documentation on
+        how to setup properly your Apache server!
 
     .. note:: if a ``.htaccess`` file already exists, this is not overwritten.
     """
@@ -218,9 +223,9 @@ def get_secret_key():
     Raise ConfigurationError if the secret key cannot be found/read from the disk.
     """
     from aiida.common.exceptions import ConfigurationError
-    from aiida.backends.settings import IN_DOC_MODE
+    from aiida.backends.settings import IN_RT_DOC_MODE
 
-    if IN_DOC_MODE:
+    if IN_RT_DOC_MODE:
         return ""
 
     aiida_dir = os.path.expanduser(AIIDA_CONFIG_FOLDER)
