@@ -182,15 +182,101 @@ class AbstractComputer(object):
     def set(self, **kwargs):
         pass
 
-    @abstractstaticmethod
-    def get_db_columns():
+    @staticmethod
+    def get_schema():
         """
-        This method returns a list with the column names and types of the
-        table
-        corresponding to this class.
-        :return: a list with the names of the columns
+        Every node property contains:
+            - display_name: display name of the property
+            - help text: short help text of the property
+            - is_foreign_key: is the property foreign key to other type of the node
+            - type: type of the property. e.g. str, dict, int
+
+        :return: get schema of the computer
         """
-        pass
+        return {
+            "description": {
+                "display_name": "Description",
+                "help_text": "short description of the Computer",
+                "is_foreign_key": False,
+                "type": "str"
+            },
+            "enabled": {
+                "display_name": "Enabled",
+                "help_text": "True(False) if the computer is(not) enabled to run jobs",
+                "is_foreign_key": False,
+                "type": "bool"
+            },
+            "hostname": {
+                "display_name": "Host",
+                "help_text": "Name of the host",
+                "is_foreign_key": False,
+                "type": "str"
+            },
+            "id": {
+                "display_name": "Id",
+                "help_text": "Id of the object",
+                "is_foreign_key": False,
+                "type": "int"
+            },
+            "name": {
+                "display_name": "Name",
+                "help_text": "Name of the object",
+                "is_foreign_key": False,
+                "type": "str"
+            },
+            "scheduler_type": {
+                "display_name": "Scheduler",
+                "help_text": "Scheduler type",
+                "is_foreign_key": False,
+                "type": "str",
+                "valid_choices": {
+                    "direct": {
+                        "doc": "Support for the direct execution bypassing schedulers."
+                    },
+                    "pbsbaseclasses.PbsBaseClass": {
+                        "doc": "Base class with support for the PBSPro scheduler"
+                    },
+                    "pbspro": {
+                        "doc": "Subclass to support the PBSPro scheduler"
+                    },
+                    "sge": {
+                        "doc": "Support for the Sun Grid Engine scheduler and its variants/forks (Son of Grid Engine, Oracle Grid Engine, ...)"
+                    },
+                    "slurm": {
+                        "doc": "Support for the SLURM scheduler (http://slurm.schedmd.com/)."
+                    },
+                    "torque": {
+                        "doc": "Subclass to support the Torque scheduler.."
+                    }
+                }
+            },
+            "transport_params": {
+                "display_name": "",
+                "help_text": "Transport Parameters",
+                "is_foreign_key": False,
+                "type": "str"
+            },
+            "transport_type": {
+                "display_name": "Transport type",
+                "help_text": "Transport Type",
+                "is_foreign_key": False,
+                "type": "str",
+                "valid_choices": {
+                    "local": {
+                        "doc": "Support copy and command execution on the same host on which AiiDA is running via direct file copy and execution commands."
+                    },
+                    "ssh": {
+                        "doc": "Support connection, command execution and data transfer to remote computers via SSH+SFTP."
+                    }
+                }
+            },
+            "uuid": {
+                "display_name": "Unique ID",
+                "help_text": "Universally Unique Identifier",
+                "is_foreign_key": False,
+                "type": "unicode"
+            }
+        }
 
     @abstractclassmethod
     def list_names(cls):
