@@ -9,23 +9,30 @@
 ###########################################################################
 from abc import ABCMeta, abstractmethod, abstractproperty
 
-import collections
-import logging
 import os
 import types
+import logging
+import importlib
+import collections
+
+try:
+    import pathlib
+except ImportError:
+    import pathlib2 as pathlib
 
 from aiida.common.exceptions import (InternalError, ModificationNotAllowed,
                                      UniquenessError, ValidationError)
 from aiida.common.folders import SandboxFolder
 from aiida.common.utils import abstractclassmethod
 from aiida.common.utils import combomethod
-
+from aiida.common.caching import get_use_cache
 from aiida.common.links import LinkType
 from aiida.common.lang import override
 from aiida.common.old_pluginloader import get_query_type_string
 from aiida.backends.utils import validate_attribute_key
 
 _NO_DEFAULT = tuple()
+_HASH_EXTRA_KEY = '_aiida_hash'
 
 
 def clean_value(value):
@@ -138,10 +145,15 @@ class AbstractNode(object):
     # See documentation in the set() method.
     _set_incompatibilities = []
 
+    # A list of attribute names that will be ignored when creating the hash.
+    _hash_ignored_attributes = []
+
+    # Flag that determines whether the class can be cached.
+    _cacheable = True
+
     def get_desc(self):
         """
-        Returns a string with infos retrieved from a node's
-        properties.
+        Returns a string with infos retrieved from a node's properties.
         This method is actually overwritten by the inheriting classes
 
         :return: a description string
@@ -149,13 +161,92 @@ class AbstractNode(object):
         return ""
 
     @staticmethod
-    def get_db_columns():
+    def get_schema():
         """
-        This method returns a list with the column names and types of the table
-        corresponding to this class.
-        :return: a list with the names of the columns
+        Every node property contains:
+            - display_name: display name of the property
+            - help text: short help text of the property
+            - is_foreign_key: is the property foreign key to other type of the node
+            - type: type of the property. e.g. str, dict, int
+
+        :return: get schema of the node
         """
-        pass
+        return {
+            "attributes": {
+                "display_name": "Attributes",
+                "help_text": "Attributes of the node",
+                "is_foreign_key": False,
+                "type": "dict"
+            },
+            "attributes.state": {
+                "display_name": "State",
+                "help_text": "AiiDA state of the calculation",
+                "is_foreign_key": False,
+                "type": ""
+            },
+            "ctime": {
+                "display_name": "Creation time",
+                "help_text": "Creation time of the node",
+                "is_foreign_key": False,
+                "type": "datetime.datetime"
+            },
+            "extras": {
+                "display_name": "Extras",
+                "help_text": "Extras of the node",
+                "is_foreign_key": False,
+                "type": "dict"
+            },
+            "id": {
+                "display_name": "Id",
+                "help_text": "Id of the object",
+                "is_foreign_key": False,
+                "type": "int"
+            },
+            "label": {
+                "display_name": "Label",
+                "help_text": "User-assigned label",
+                "is_foreign_key": False,
+                "type": "str"
+            },
+            "mtime": {
+                "display_name": "Last Modification time",
+                "help_text": "Last modification time",
+                "is_foreign_key": False,
+                "type": "datetime.datetime"
+            },
+            "type": {
+                "display_name": "Type",
+                "help_text": "Code type",
+                "is_foreign_key": False,
+                "type": "str"
+            },
+            "user_id": {
+                "display_name": "Id of creator",
+                "help_text": "Id of the user that created the node",
+                "is_foreign_key": True,
+                "related_column": "id",
+                "related_resource": "_dbusers",
+                "type": "int"
+            },
+            "uuid": {
+                "display_name": "Unique ID",
+                "help_text": "Universally Unique Identifier",
+                "is_foreign_key": False,
+                "type": "unicode"
+            },
+            "nodeversion": {
+                "display_name": "Node version",
+                "help_text": "Version of the node",
+                "is_foreign_key": False,
+                "type": "int"
+            },
+            "process_type": {
+                "display_name": "Process type",
+                "help_text": "Process type",
+                "is_foreign_key": False,
+                "type": "str"
+            }
+        }
 
     @property
     def logger(self):
@@ -193,20 +284,6 @@ class AbstractNode(object):
         """
         pass
 
-    @property
-    def ctime(self):
-        """
-        Return the creation time of the node.
-        """
-        return self.dbnode.ctime
-
-    @property
-    def mtime(self):
-        """
-        Return the modification time of the node.
-        """
-        return self.dbnode.mtime
-
     def __int__(self):
         if self._to_be_stored:
             return None
@@ -237,6 +314,20 @@ class AbstractNode(object):
         """
         return not self._to_be_stored
 
+    @abstractproperty
+    def ctime(self):
+        """
+        Return the creation time of the node.
+        """
+        pass
+
+    @abstractproperty
+    def mtime(self):
+        """
+        Return the modification time of the node.
+        """
+        pass
+
     def __repr__(self):
         return '<{}: {}>'.format(self.__class__.__name__, str(self))
 
@@ -248,8 +339,7 @@ class AbstractNode(object):
 
     def _init_internal_params(self):
         """
-        Set here the default values for this class; this method
-        is automatically called by the init.
+        Set the default values for this class; this method is automatically called by the init.
 
         :note: if you inherit this function, ALWAYS remember to
           call super()._init_internal_params() as the first thing
@@ -337,7 +427,7 @@ class AbstractNode(object):
                     raise ValueError("Cannot set {} directly when creating "
                                      "the node or using the .set() method; "
                                      "use the specific method instead.".format(
-                                         incomp[0]))
+                        incomp[0]))
                 else:
                     raise ValueError("Cannot set {} at the same time".format(
                         " and ".join(incomp)))
@@ -356,6 +446,15 @@ class AbstractNode(object):
                                  "callable!".format(k))
             method(v)
 
+    @abstractproperty
+    def type(self):
+        """
+        Get the type of the node.
+
+        :return: a string.
+        """
+        pass
+
     @property
     def label(self):
         """
@@ -363,7 +462,7 @@ class AbstractNode(object):
 
         :return: a string.
         """
-        return self.dbnode.label
+        return self._get_db_label_field()
 
     @label.setter
     def label(self, label):
@@ -374,10 +473,19 @@ class AbstractNode(object):
         """
         self._update_db_label_field(label)
 
+    @abstractmethod
+    def _get_db_label_field(self):
+        """
+        Get the label field acting directly on the DB
+
+        :return: a string.
+        """
+        pass
+
     @abstractmethod
     def _update_db_label_field(self, field_value):
         """
-        Update the label field acting directly on the DB
+        Set the label field acting directly on the DB
         """
         pass
 
@@ -387,8 +495,9 @@ class AbstractNode(object):
         Get the description of the node.
 
         :return: a string
+        :rtype: str
         """
-        return self.dbnode.description
+        return self._get_db_description_field()
 
     @description.setter
     def description(self, desc):
@@ -399,6 +508,13 @@ class AbstractNode(object):
         """
         self._update_db_description_field(desc)
 
+    @abstractmethod
+    def _get_db_description_field(self):
+        """
+        Get the description of this node, acting directly at the DB level
+        """
+        pass
+
     @abstractmethod
     def _update_db_description_field(self, field_value):
         """
@@ -421,13 +537,14 @@ class AbstractNode(object):
         """
         return True
 
+    @abstractmethod
     def get_user(self):
         """
         Get the user.
 
-        :return: a Django DbUser model object
+        :return: a DbUser model object
         """
-        return self.dbnode.user
+        pass
 
     def _has_cached_links(self):
         """
@@ -647,28 +764,24 @@ class AbstractNode(object):
 
         return new_outputs
 
-    def get_inputs(self,
-                   node_type=None,
-                   also_labels=False,
-                   only_in_db=False,
-                   link_type=None):
+    def get_inputs(self, node_type=None, also_labels=False, only_in_db=False, link_type=None):
         """
         Return a list of nodes that enter (directly) in this node
 
         :param node_type: If specified, should be a class, and it filters only
             elements of that specific type (or a subclass of 'type')
         :param also_labels: If False (default) only return a list of input nodes.
-                If True, return a list of tuples, where each tuple has the
-                following format: ('label', Node), with 'label' the link label,
-                and Node a Node instance or subclass
+            If True, return a list of tuples, where each tuple has the
+            following format: ('label', Node), with 'label' the link label,
+            and Node a Node instance or subclass
         :param only_in_db: Return only the inputs that are in the database,
-                ignoring those that are in the local cache. Otherwise, return
-                all links.
+            ignoring those that are in the local cache. Otherwise, return
+            all links.
         :param link_type: Only get inputs of this link type, if None then
-                returns all inputs of all link types.
+            returns all inputs of all link types.
         """
         if link_type is not None and not isinstance(link_type, LinkType):
-            raise TypeError("link_type should be a LinkType object")
+            raise TypeError('link_type should be a LinkType object')
 
         inputs_list = self._get_db_input_links(link_type=link_type)
 
@@ -678,19 +791,18 @@ class AbstractNode(object):
 
             for label, v in self._inputlinks_cache.iteritems():
                 src = v[0]
+                input_link_type = v[1]
                 if label in input_list_keys:
-                    raise InternalError(
-                        "There exist a link with the same name "
-                        "'{}' both in the DB and in the internal "
-                        "cache for node pk= {}!".format(label, self.pk))
-                inputs_list.append((label, src))
+                    raise InternalError("There exist a link with the same name '{}' both in the DB "
+                                        "and in the internal cache for node pk= {}!".format(label, self.pk))
+
+                if link_type is None or input_link_type is link_type:
+                    inputs_list.append((label, src))
 
         if node_type is None:
             filtered_list = inputs_list
         else:
-            filtered_list = [
-                i for i in inputs_list if isinstance(i[1], node_type)
-            ]
+            filtered_list = [i for i in inputs_list if isinstance(i[1], node_type)]
 
         if also_labels:
             return list(filtered_list)
@@ -708,33 +820,33 @@ class AbstractNode(object):
         """
         pass
 
-    # pylint: disable=no-else-return
     @override
-    def get_outputs(self, type=None, also_labels=False, link_type=None):
+    def get_outputs(self, node_type=None, also_labels=False, link_type=None):
         """
         Return a list of nodes that exit (directly) from this node
 
-        :param type: if specified, should be a class, and it filters only
-                elements of that specific type (or a subclass of 'type')
+        :param node_type: if specified, should be a class, and it filters only
+            elements of that specific node_type (or a subclass of 'node_type')
         :param also_labels: if False (default) only return a list of input nodes.
-                If True, return a list of tuples, where each tuple has the
-                following format: ('label', Node), with 'label' the link label,
-                and Node a Node instance or subclass
+            If True, return a list of tuples, where each tuple has the
+            following format: ('label', Node), with 'label' the link label,
+            and Node a Node instance or subclass
         :param link_type: Only return outputs connected by links of this type.
         """
+        if link_type is not None and not isinstance(link_type, LinkType):
+            raise TypeError('link_type should be a LinkType object')
+
         outputs_list = self._get_db_output_links(link_type=link_type)
 
-        if type is None:
-            if also_labels:
-                return list(outputs_list)
-            else:
-                return [i[1] for i in outputs_list]
+        if node_type is None:
+            filtered_list = outputs_list
         else:
-            filtered_list = (i for i in outputs_list if isinstance(i[1], type))
-            if also_labels:
-                return list(filtered_list)
-            else:
-                return [i[1] for i in filtered_list]
+            filtered_list = (i for i in outputs_list if isinstance(i[1], node_type))
+
+        if also_labels:
+            return list(filtered_list)
+
+        return [i[1] for i in filtered_list]
 
     @abstractmethod
     def _get_db_output_links(self, link_type):
@@ -747,17 +859,14 @@ class AbstractNode(object):
         """
         pass
 
+    @abstractmethod
     def get_computer(self):
         """
         Get the computer associated to the node.
 
         :return: the Computer object or None.
         """
-        from aiida.orm.computer import Computer
-        if self.dbnode.dbcomputer is None:
-            return None
-        else:
-            return Computer(dbcomputer=self.dbnode.dbcomputer)
+        pass
 
     def set_computer(self, computer):
         """
@@ -1130,8 +1239,8 @@ class AbstractNode(object):
             # Return without value, meaning that this is an empty generator
             return
             yield  # Needed after return to convert it to a generator
-        for _ in self._db_iterextras():
-            yield _
+        for extra in self._db_iterextras():
+            yield extra
 
     def iterattrs(self):
         """
@@ -1256,7 +1365,7 @@ class AbstractNode(object):
         pass
 
     @abstractmethod
-    def copy(self):
+    def copy(self, **kwargs):
         """
         Return a copy of the current object to work with, not stored yet.
 
@@ -1426,9 +1535,9 @@ class AbstractNode(object):
             raise ValueError("The path in get_abs_path must be relative")
         return self.folder.get_subfolder(
             section, reset_limit=True).get_abs_path(
-                path, check_existence=True)
+            path, check_existence=True)
 
-    def store_all(self, with_transaction=True):
+    def store_all(self, with_transaction=True, use_cache=None):
         """
         Store the node, together with all input links, if cached, and also the
         linked nodes, if they were not stored yet.
@@ -1453,10 +1562,10 @@ class AbstractNode(object):
                     "unstored parents, cannot proceed (only direct parents "
                     "can be unstored and will be stored by store_all, not "
                     "grandparents or other ancestors".format(parent_node.uuid))
-        return self._db_store_all(with_transaction)
+        return self._db_store_all(with_transaction, use_cache=use_cache)
 
     @abstractmethod
-    def _db_store_all(self, with_transaction=True):
+    def _db_store_all(self, with_transaction=True, use_cache=None):
         """
         Store the node, together with all input links, if cached, and also the
         linked nodes, if they were not stored yet.
@@ -1464,6 +1573,9 @@ class AbstractNode(object):
         :parameter with_transaction: if False, no transaction is used. This
           is meant to be used ONLY if the outer calling function has already
           a transaction open!
+
+        :param use_cache: Determines whether caching is used to find an equivalent node.
+        :type use_cache: bool
         """
         pass
 
@@ -1524,7 +1636,7 @@ class AbstractNode(object):
         """
         pass
 
-    def store(self, with_transaction=True):
+    def store(self, with_transaction=True, use_cache=None):
         """
         Store a new node in the DB, also saving its repository directory
         and attributes.
@@ -1553,8 +1665,17 @@ class AbstractNode(object):
             # the case.
             self._check_are_parents_stored()
 
-            # call implementation-dependent store method
-            self._db_store(with_transaction)
+            # Get default for use_cache if it's not set explicitly.
+            if use_cache is None:
+                use_cache = get_use_cache(type(self))
+            # Retrieve the cached node.
+            same_node = self._get_same_node() if use_cache else None
+            if same_node is not None:
+                self._store_from_cache(same_node, with_transaction=with_transaction)
+                self._add_outputs_from_cache(same_node)
+            else:
+                # call implementation-dependent store method
+                self._db_store(with_transaction)
 
             # Set up autogrouping used by verdi run
             from aiida.orm.autogroup import current_autogroup, Autogroup, VERDIAUTOGROUP_TYPE
@@ -1576,6 +1697,40 @@ class AbstractNode(object):
         # n = Node().store()
         return self
 
+    def _store_from_cache(self, cache_node, with_transaction):
+        from aiida.orm.mixins import Sealable
+        new_node = type(cache_node)()
+        new_node._dbnode.type = cache_node._dbnode.type  # Inherit type
+        new_node.label = cache_node.label  # Inherit label
+        new_node.description = cache_node.description  # Inherit description
+        new_node._dbnode.dbcomputer = cache_node._dbnode.dbcomputer  # Inherit computer
+
+        for k, v in cache_node.iterattrs():
+            if k != Sealable.SEALED_KEY:
+                new_node._set_attr(k, v)
+
+        new_node.folder.replace_with_folder(cache_node.folder.abspath, move=False, overwrite=True)
+
+        inputlinks_cache = self._inputlinks_cache
+        # "impersonate" the copied node by getting all its attributes
+        self.__dict__ = new_node.__dict__
+        # restore the input links
+        self._inputlinks_cache = inputlinks_cache
+
+        # Make sure the node doesn't have any RETURN links
+        if cache_node.get_outputs(link_type=LinkType.RETURN):
+            raise ValueError("Cannot use cache from nodes with RETURN links.")
+
+        self.store(with_transaction=with_transaction, use_cache=False)
+        self.set_extra('_aiida_cached_from', cache_node.uuid)
+
+    def _add_outputs_from_cache(self, cache_node):
+        # add CREATE links
+        output_mapping = {}
+        for linkname, out_node in cache_node.get_outputs(also_labels=True, link_type=LinkType.CREATE):
+            new_node = out_node.copy(include_updatable_attrs=True).store()
+            new_node.add_link_from(self, label=linkname, link_type=LinkType.CREATE)
+
     @abstractmethod
     def _db_store(self, with_transaction=True):
         """
@@ -1605,6 +1760,94 @@ class AbstractNode(object):
         if getattr(self, '_temp_folder', None) is not None:
             self._temp_folder.erase()
 
+    def get_hash(self, ignore_errors=True, **kwargs):
+        """
+        Making a hash based on my attributes
+        """
+        from aiida.common.hashing import make_hash
+        try:
+            return make_hash(self._get_objects_to_hash(), **kwargs)
+        except Exception as e:
+            if ignore_errors:
+                return None
+            else:
+                raise e
+
+    def _get_objects_to_hash(self):
+        """
+        Return a list of objects which should be included in the hash.
+        """
+        computer = self.get_computer()
+        return [
+            importlib.import_module(
+                self.__module__.split('.', 1)[0]
+            ).__version__,
+            {
+                key: val for key, val in self.get_attrs().items()
+                if (
+                    (key not in self._hash_ignored_attributes) and
+                    (key not in getattr(self, '_updatable_attributes', tuple()))
+            )
+            },
+            self.folder,
+            computer.uuid if computer is not None else None
+        ]
+
+    def rehash(self):
+        """
+        Re-generates the stored hash of the Node.
+        """
+        self.set_extra(_HASH_EXTRA_KEY, self.get_hash())
+
+    def clear_hash(self):
+        """
+        Sets the stored hash of the Node to None.
+        """
+        self.set_extra(_HASH_EXTRA_KEY, None)
+
+    def _get_same_node(self):
+        """
+        Returns a stored node from which the current Node can be cached, meaning that the returned Node is a valid cache, and its ``_aiida_hash`` attribute matches ``self.get_hash()``.
+
+        If there are multiple valid matches, the first one is returned. If no matches are found, ``None`` is returned.
+
+        Note that after ``self`` is stored, this function can return ``self``.
+        """
+        try:
+            return next(self._iter_all_same_nodes())
+        except StopIteration:
+            return None
+
+    def get_all_same_nodes(self):
+        """
+        Return a list of stored nodes which match the type and hash of the current node. For the stored nodes, the ``_aiida_hash`` extra is checked to determine the hash, while ``self.get_hash()`` is executed on the current node.
+
+        Only nodes which are a valid cache are returned. If the current node is already stored, it can be included in the returned list if ``self.get_hash()`` matches its ``_aiida_hash``.
+        """
+        return list(self._iter_all_same_nodes())
+
+    def _iter_all_same_nodes(self):
+        """
+        Returns an iterator of all same nodes.
+        """
+        if not self._cacheable:
+            return iter(())
+
+        from aiida.orm.querybuilder import QueryBuilder
+
+        hash_ = self.get_hash()
+        if hash_:
+            qb = QueryBuilder()
+            qb.append(self.__class__, filters={'extras._aiida_hash': hash_}, project='*', subclassing=False)
+            same_nodes = (n[0] for n in qb.iterall())
+        return (n for n in same_nodes if n._is_valid_cache())
+
+    def _is_valid_cache(self):
+        """
+        Subclass hook to exclude certain Nodes (e.g. failed calculations) from being considered in the caching process.
+        """
+        return True
+
     @property
     def out(self):
         """
@@ -1626,7 +1869,6 @@ class AbstractNode(object):
         """
         return NodeInputManager(self)
 
-
     @property
     def has_children(self):
         """
@@ -1636,11 +1878,10 @@ class AbstractNode(object):
         from aiida.orm.querybuilder import QueryBuilder
         from aiida.orm import Node
         first_desc = QueryBuilder().append(
-            Node, filters={'id':self.pk}, tag='self').append(
+            Node, filters={'id': self.pk}, tag='self').append(
             Node, descendant_of='self', project='id').first()
         return bool(first_desc)
 
-
     @property
     def has_parents(self):
         """
@@ -1650,7 +1891,7 @@ class AbstractNode(object):
         from aiida.orm.querybuilder import QueryBuilder
         from aiida.orm import Node
         first_ancestor = QueryBuilder().append(
-            Node, filters={'id':self.pk}, tag='self').append(
+            Node, filters={'id': self.pk}, tag='self').append(
             Node, ancestor_of='self', project='id').first()
         return bool(first_ancestor)
 
