@@ -120,6 +120,7 @@ class AiidaApi(Api):
                           '/nodes/',
                           '/nodes/schema/',
                           '/nodes/statistics/',
+                          '/nodes/types/',
                           '/nodes/page/',
                           '/nodes/page/<int:page>/',
                           '/nodes/<id>/',
@@ -139,6 +140,7 @@ class AiidaApi(Api):
 
         self.add_resource(Calculation,
                           '/calculations/',
+                          '/calculations/types/',
                           '/calculations/schema/',
                           '/calculations/page/',
                           '/calculations/page/<int:page>/',
@@ -160,6 +162,7 @@ class AiidaApi(Api):
 
         self.add_resource(Data,
                           '/data/',
+                          '/data/types/',
                           '/data/schema/',
                           '/data/page/',
                           '/data/page/<int:page>',
@@ -181,6 +184,7 @@ class AiidaApi(Api):
 
         self.add_resource(Code,
                           '/codes/',
+                          '/codes/types/',
                           '/codes/schema/',
                           '/codes/page/',
                           '/codes/page/<int:page>/',
