@@ -216,6 +216,14 @@ class Utils(object):
                     "admit further fields")
             else:
                 return (resource_type, page, id, query_type)
+        elif path[0] == 'types':
+            query_type = path.pop(0)
+            if path:
+                raise RestInputValidationError(
+                    "url requesting statistics resources do not "
+                    "admit further fields")
+            else:
+                return (resource_type, page, id, query_type)
         elif path[0] == "io" or path[0] == "content":
             path.pop(0)
             query_type = path.pop(0)
@@ -509,6 +517,10 @@ class Utils(object):
         filename = None
         rtype = None
 
+        # io tree limit parameters
+        tree_in_limit = None
+        tree_out_limit = None
+
         ## Count how many time a key has been used for the filters and check if
         # reserved keyword
         # have been used twice,
@@ -575,6 +587,12 @@ class Utils(object):
             raise RestInputValidationError(
                 "You cannot specify rtype more than "
                 "once")
+        if 'in_limit' in field_counts.keys() and field_counts['in_limit'] > 1:
+            raise RestInputValidationError(
+                "You cannot specify in_limit more than once")
+        if 'out_limit' in field_counts.keys() and field_counts['out_limit'] > 1:
+            raise RestInputValidationError(
+                "You cannot specify out_limit more than once")
 
         ## Extract results
         for field in field_list:
@@ -675,6 +693,20 @@ class Utils(object):
                         "only assignment operator '=' "
                         "is permitted after 'rtype'")
 
+            elif field[0] == 'in_limit':
+                if field[1] == '=':
+                    tree_in_limit = field[2]
+                else:
+                    raise RestInputValidationError(
+                        "only assignment operator '=' is permitted after 'in_limit'")
+
+            elif field[0] == 'out_limit':
+                if field[1] == '=':
+                    tree_out_limit = field[2]
+                else:
+                    raise RestInputValidationError(
+                        "only assignment operator '=' is permitted after 'out_limit'")
+
             else:
 
                 ## Construct the filter entry.
@@ -707,7 +739,7 @@ class Utils(object):
         #     limit = self.LIMIT_DEFAULT
 
         return (limit, offset, perpage, orderby, filters, alist, nalist, elist,
-                nelist, downloadformat, visformat, filename, rtype)
+                nelist, downloadformat, visformat, filename, rtype, tree_in_limit, tree_out_limit)
 
     def parse_query_string(self, query_string):
         """
