@@ -518,8 +518,33 @@ class NodeTranslator(BaseTranslator):
         qmanager = QueryFactory()()
         return qmanager.get_creation_statistics(user_pk=user_pk)
 
+    def get_types(self):
+        """
+        return available distinct types of nodes from database
+        """
+        from aiida.orm.querybuilder import QueryBuilder
 
-    def get_io_tree(self, uuid_pattern):
+        qb = QueryBuilder()
+        qb.append(self._aiida_class, project=["type"])
+        qb_response = qb.distinct().all()
+
+        results = {}
+        if len(qb_response) > 0:
+            for ntype in qb_response:
+                ntype = ntype[0]
+                ntype_parts = ntype.split(".")
+                if len(ntype_parts) > 0:
+                    dict_key =ntype_parts[0]
+                    if dict_key not in results.keys():
+                        results[dict_key] = []
+                    results[dict_key].append(ntype)
+
+        for key, values in results.items():
+            results[key] = sorted(values)
+
+        return results
+
+    def get_io_tree(self, uuid_pattern, tree_in_limit, tree_out_limit):
         from aiida.orm.querybuilder import QueryBuilder
         from aiida.orm.node import Node
 
@@ -552,6 +577,7 @@ class NodeTranslator(BaseTranslator):
             pk = mainNode.pk
             uuid = mainNode.uuid
             nodetype = mainNode.type
+            nodelabel = mainNode.label
             display_type = nodetype.split('.')[-2]
             description = mainNode.get_desc()
             if description == '':
@@ -562,6 +588,7 @@ class NodeTranslator(BaseTranslator):
                 "nodeid": pk,
                 "nodeuuid": uuid,
                 "nodetype": nodetype,
+                "nodelabel": nodelabel,
                 "displaytype": display_type,
                 "group": "mainNode",
                 "description": description,
@@ -569,81 +596,128 @@ class NodeTranslator(BaseTranslator):
             })
         nodeCount += 1
 
+
         # get all inputs
         qb = QueryBuilder()
         qb.append(Node, tag="main", project=['*'],
                   filters=self._id_filter)
-        qb.append(Node, tag="in", project=['*'], edge_project=['label'],
+        qb.append(Node, tag="in", project=['*'], edge_project=['label', 'type'],
                   input_of='main')
+        if tree_in_limit is not None:
+            qb.limit(tree_in_limit)
 
-        if qb.count() > 0:
+        input_node_pks = {}
+        sent_no_of_incomings = qb.count()
+
+        if sent_no_of_incomings > 0:
             for input in qb.iterdict():
                 node = input['in']['*']
-                linktype = input['main--in']['label']
                 pk = node.pk
-                uuid = node.uuid
-                nodetype = node.type
-                display_type = nodetype.split('.')[-2]
-                description = node.get_desc()
-                if description == '':
-                    description = node.type.split('.')[-2]
+                linklabel = input['main--in']['label']
+                linktype = input['main--in']['type']
 
-                nodes.append({
-                    "id": nodeCount,
-                    "nodeid": pk,
-                    "nodeuuid": uuid,
-                    "nodetype": nodetype,
-                    "displaytype": display_type,
-                    "group": "inputs",
-                    "description": description,
-                    "linktype": linktype,
-                    "shape": get_node_shape(nodetype)
-                })
+                # add node if it is not present
+                if pk not in input_node_pks.keys():
+                    input_node_pks[pk] = nodeCount
+                    uuid = node.uuid
+                    nodetype = node.type
+                    nodelabel = node.label
+                    display_type = nodetype.split('.')[-2]
+                    description = node.get_desc()
+                    if description == '':
+                        description = node.type.split('.')[-2]
+
+                    nodes.append({
+                        "id": nodeCount,
+                        "nodeid": pk,
+                        "nodeuuid": uuid,
+                        "nodetype": nodetype,
+                        "nodelabel": nodelabel,
+                        "displaytype": display_type,
+                        "group": "inputs",
+                        "description": description,
+                        "linklabel": linklabel,
+                        "linktype": linktype,
+                        "shape": get_node_shape(nodetype)
+                    })
+                    nodeCount += 1
+
+                from_edge = input_node_pks[pk]
                 edges.append({
-                    "from": nodeCount,
+                    "from": from_edge,
                     "to": 0,
                     "arrows": "to",
                     "color": {"inherit": 'from'},
-                    "linktype": linktype,
+                    "label": linktype,
                 })
-                nodeCount += 1
+
 
         # get all outputs
         qb = QueryBuilder()
         qb.append(Node, tag="main", project=['*'],
                   filters=self._id_filter)
-        qb.append(Node, tag="out", project=['*'], edge_project=['label'],
+        qb.append(Node, tag="out", project=['*'], edge_project=['label', 'type'],
                   output_of='main')
-        if qb.count() > 0:
+        if tree_out_limit is not None:
+            qb.limit(tree_out_limit)
+
+        output_node_pks = {}
+        sent_no_of_outgoings = qb.count()
+
+        if sent_no_of_outgoings > 0:
             for output in qb.iterdict():
                 node = output['out']['*']
-                linktype = output['main--out']['label']
                 pk = node.pk
-                uuid = node.uuid
-                nodetype = node.type
-                display_type = nodetype.split('.')[-2]
-                description = node.get_desc()
-                if description == '':
-                    description = node.type.split('.')[-2]
+                linklabel = output['main--out']['label']
+                linktype = output['main--out']['type']
 
-                nodes.append({
-                    "id": nodeCount,
-                    "nodeid": pk,
-                    "nodeuuid": uuid,
-                    "nodetype": nodetype,
-                    "displaytype": display_type,
-                    "group": "outputs",
-                    "description": description,
-                    "linktype": linktype,
-                    "shape": get_node_shape(nodetype)
-                })
+                # add node if it is not present
+                if pk not in output_node_pks.keys():
+                    output_node_pks[pk] = nodeCount
+                    uuid = node.uuid
+                    nodetype = node.type
+                    nodelabel = node.label
+                    display_type = nodetype.split('.')[-2]
+                    description = node.get_desc()
+                    if description == '':
+                        description = node.type.split('.')[-2]
+
+                    nodes.append({
+                        "id": nodeCount,
+                        "nodeid": pk,
+                        "nodeuuid": uuid,
+                        "nodetype": nodetype,
+                        "nodelabel": nodelabel,
+                        "displaytype": display_type,
+                        "group": "outputs",
+                        "description": description,
+                        "linklabel": linklabel,
+                        "linktype": linktype,
+                        "shape": get_node_shape(nodetype)
+                    })
+                    nodeCount += 1
+
+                to_edge = output_node_pks[pk]
                 edges.append({
                     "from": 0,
-                    "to": nodeCount,
+                    "to": to_edge,
                     "arrows": "to",
                     "color": {"inherit": 'to'},
-                    "linktype": linktype
+                    "label": linktype
                 })
-                nodeCount += 1
 
-        return {"nodes": nodes, "edges": edges}
+        # count total no of nodes
+        qb = QueryBuilder()
+        qb.append(Node, tag="main", project=['id'], filters=self._id_filter)
+        qb.append(Node, tag="in", project=['id'], input_of='main')
+        total_no_of_incomings = qb.count()
+
+        qb = QueryBuilder()
+        qb.append(Node, tag="main", project=['id'], filters=self._id_filter)
+        qb.append(Node, tag="out", project=['id'], output_of='main')
+        total_no_of_outgoings = qb.count()
+
+
+        return {"nodes": nodes, "edges": edges, "total_no_of_incomings": total_no_of_incomings,
+                "total_no_of_outgoings": total_no_of_outgoings, "sent_no_of_incomings": sent_no_of_incomings,
+                "sent_no_of_outgoings": sent_no_of_outgoings}
