@@ -372,21 +372,25 @@ def _inline_to_standalone_script(calc):
     """
     Create executable Python script for execution of inline script.
 
-    .. note:: the output bash script may not always be correct, since it
-        is simply formed from:
-        * contents of the file, which contains the original ``\*_inline``
-          function;
-        * call of the original ``\*_inline`` function with input nodes;
-        * storing of the output nodes.
-        Execution of generated bash script should result in
-        ModificationNotAllowed exception, since the nodes, that are
-        created by the ``\*_inline`` function, are already stored.
+    .. note:: 
+    
+       the output bash script may not always be correct, since it
+       is simply formed from:
+
+       * contents of the file, which contains the original ``\*_inline``
+         function;
+       * call of the original ``\*_inline`` function with input nodes;
+       * storing of the output nodes.
+
+       Execution of generated bash script should result in
+       ModificationNotAllowed exception, since the nodes, that are
+       created by the ``\*_inline`` function, are already stored.
     """
     input_dict = calc.get_inputs_dict()
     args = ["{}=load_node('{}')".format(x, input_dict[x].uuid)
             for x in input_dict.keys()]
     args_string = ",\n    ".join(sorted(args))
-    code_string = calc.get_attr('source_file').encode('utf-8')
+    code_string = calc.get_attr('source_code').encode('utf-8')
     if calc.get_attr('namespace', '__main__').startswith('aiida.'):
         code_string = "from {} import {}".format(calc.get_attr('namespace', '__main__'),
                                                  calc.get_attr('function_name','f'))
@@ -711,7 +715,7 @@ def _collect_tags(node, calc,parameters=None,
 
         with SandboxFolder() as folder:
             try:
-                export_tree([node.dbnode], folder=folder, silent=True,
+                export_tree([node], folder=folder, silent=True,
                             allowed_licenses=['CC0'])
             except LicensingException as e:
                 raise LicensingException(e.message + \
@@ -875,8 +879,8 @@ def add_metadata_inline(what, node=None, parameters=None, args=None):
     for tag in node.values[dataname].keys():
         datablock[tag] = node.values[dataname][tag]
     datablocks.append(datablock)
-    for loop in node.values[dataname].loops:
-        loops[loop.keys()[0]] = loop.keys()
+    for loop in node.values[dataname].loops.values():
+        loops[loop[0]] = loop
 
     # Unpacking the kwargs from ParameterData
     kwargs = {}
@@ -976,7 +980,7 @@ def export_cifnode(what, parameters=None, trajectory_index=None,
             raise ValueError("Supplied parameters are not an "
                              "instance of ParameterData")
     elif calc is not None:
-        params = calc.get_outputs(type=ParameterData, link_type=LinkType.CREATE)
+        params = calc.get_outputs(node_type=ParameterData, link_type=LinkType.CREATE)
         if len(params) == 1:
             parameters = params[0]
         elif len(params) > 0:
