@@ -26,15 +26,15 @@ def update_req_for_rtd(pre_commit):
 
     import setup_requirements
 
-    reqs = set(
-        setup_requirements.extras_require['docs'] + setup_requirements.
-        extras_require['rest'] + setup_requirements.extras_require['testing'] +
-        setup_requirements.extras_require[':python_version < "3"'] +
-        # To avoid that it requires also the postgres libraries
-        [
-            p for p in setup_requirements.install_requires
-            if not p.startswith('psycopg2')
-        ])
+    reqs = set(setup_requirements.extras_require['docs'] +
+               setup_requirements.extras_require['rest'] +
+               setup_requirements.extras_require['testing'] +
+               setup_requirements.extras_require[':python_version < "3"'] +
+               # To avoid that it requires also the postgres libraries
+               [
+                   p for p in setup_requirements.install_requires
+                   if not p.startswith('psycopg2')
+               ])
     reqs_str = "\n".join(sorted(reqs))
 
     basename = 'requirements_for_rtd.txt'
